# Technology Management Platform
#
# (C) Copyright 2024 Informed Technology Solutions, LLC
#
# SPDX-License-Identifier: BSD-3-Clause
#

from PySide6 import QtCore, QtWidgets, QtGui
from PySide6.QtWidgets import QWizardPage, QLabel, QVBoxLayout, QApplication, QWizard, QFrame,\
    QRadioButton

import sys

dev_enabled = True

debug_enabled = False

license_infotext = "Libranext is a collection of software, including some written specifically for Libranext.\n\nIt's important to know that all software has a license, describing how you can use it, and if you can modify it or not. Some licenses also have additional terms.\n\nLibranext is primarily made from software that uses open-source licenses. These generally allow you to freely use, modify and distribute it, subject to the specific license terms for each piece of software. These licenses include, but are not limited to, the GNU GPL (versions 2 and 3), the BSD licenses, the MIT license, and more.\n\n Libranext may include some software, drivers, or firmware that are licensed under a proprietary license. The source code is not available, and modification is generally not permitted. These are only included as necessary to ensure that your experience as a user is the best it can be. When ane open-source alternative is available, we usually switch to it. In many cases, you can uninstall these proprietary components.\n\nBy continuing to install Libranext and the included software, you agree to the terms of their licenses."

if dev_enabled is True:
    debug_enabled = True

def createWelcomePage():
    
    page = QWizardPage()
    page.setTitle("Welcome")
    label = QLabel("Welcome to the Libranext Setup Utility!")
        
    label.setWordWrap(True)
    layout = QVBoxLayout()
    layout.addWidget(label)
    page.setLayout(layout)
    return page

def createDevWarningPage():
    
    page = QWizardPage()
    page.setTitle("Developer Information")
    label = QLabel("Warning: This is a development version. Use at your own risk!")
    
    label.setWordWrap(True)
    layout = QVBoxLayout()
    layout.addWidget(label)
    page.setLayout(layout)
    return page

def createLicensePage():
    
    page = QWizardPage()
    page.setTitle("License Overview")
    label = QLabel(license_infotext)
    
    label.setWordWrap(True)
    layout = QVBoxLayout()
    layout.addWidget(label)
    page.setLayout(layout)
    return page

def createInspectionPage():
    
    page = QWizardPage()
    page.setTitle("Inspecting Computer Configuration")
    label = QLabel("Inspection Placeholder")
    
    label.setWordWrap(True)
    layout = QVBoxLayout()
    layout.addWidget(label)
    page.setLayout(layout)
    return page

def createEditionPage():
    
    page = QWizardPage()
    page.setTitle("Choose Edition")
    label = QLabel("Edition Selection Placeholder")
    
    radioEdition1 = QRadioButton("Workstation")
    radioEdition2 = QRadioButton("Server Basic")
    radioEdition3 = QRadioButton("Virtual Server Host")
    radioEdition4 = QRadioButton("Small Office/Home Office")
    radioEdition5 = QRadioButton("Enterprise Server")
    radioEdition6 = QRadioButton("Enterprise Workstation")
    
    label.setWordWrap(True)
    layout = QVBoxLayout()
    layout.addWidget(label)
    layout.addWidget(radioEdition1)
    layout.addWidget(radioEdition2)
    layout.addWidget(radioEdition3)
    layout.addWidget(radioEdition4)
    layout.addWidget(radioEdition5)
    layout.addWidget(radioEdition6)
    page.setLayout(layout)
    return page

def createDisksPage():
    
    page = QWizardPage()
    page.setTitle("Setup Disks")
    label = QLabel("Disk Setup Placeholder")
    
    label.setWordWrap(True)
    layout = QVBoxLayout()
    layout.addWidget(label)
    page.setLayout(layout)
    return page

def createInstallationPage():
    
    page = QWizardPage()
    page.setTitle("Installation")
    label = QLabel("Installation Placeholder")
    
    label.setWordWrap(True)
    layout = QVBoxLayout()
    layout.addWidget(label)
    page.setLayout(layout)
    return page

def createStartupConfigPage():
    
    page = QWizardPage()
    page.setTitle("Configure Startup")
    label = QLabel("Startup Configuration Placeholder")
    
    label.setWordWrap(True)
    layout = QVBoxLayout()
    layout.addWidget(label)
    page.setLayout(layout)
    return page

def createFileCopyPage():
    
    page = QWizardPage()
    page.setTitle("Copying Files")
    label = QLabel("File copying Placeholder")
    
    label.setWordWrap(True)
    layout = QVBoxLayout()
    layout.addWidget(label)
    page.setLayout(layout)
    return page

def createRestartPage():
    
    page = QWizardPage()
    page.setTitle("Restart Computer")
    label = QLabel("To complete the installation, Libranext will restart your computer. \nSecond Line")
    
    label.setWordWrap(True)
    layout = QVBoxLayout()
    layout.addWidget(label)
    page.setLayout(layout)
    return page

if __name__ == "__main__":
    
    app = QApplication([])
    
    wizard = QWizard()
    wizard.addPage(createWelcomePage())
    if dev_enabled is True:
        wizard.addPage(createDevWarningPage())
    wizard.addPage(createLicensePage())
    wizard.addPage(createInspectionPage())
    wizard.addPage(createEditionPage())
    wizard.addPage(createDisksPage())
    wizard.addPage(createInstallationPage())
    wizard.addPage(createStartupConfigPage())
    wizard.addPage(createFileCopyPage())
    wizard.addPage(createRestartPage())
    wizard.setWindowTitle("Libranext Setup")
    wizard.setMinimumSize(800, 600)
    wizard.setWizardStyle(QWizard.ClassicStyle)
    wizard.show()
    sys.exit(app.exec())

